@@ -16,8 +16,9 @@ class Hujiang:
         EN = 'en'
         '''英文'''
 
-        JA = 'jp'
+        JP = 'jp'
         '''日语'''
+
         KR = 'kr'
         '''韩语'''
 
